@@ -1,6 +1,6 @@
 /***************************************************************************
  *cr
- *cr            (C) Copyright 1995-2009 The Board of Trustees of the
+ *cr            (C) Copyright 1995-2016 The Board of Trustees of the
  *cr                        University of Illinois
  *cr                         All Rights Reserved
  *cr
@@ -11,7 +11,7 @@
  *
  *      $RCSfile: dcdplugin.c,v $
  *      $Author: johns $       $Locker:  $             $State: Exp $
- *      $Revision: 1.76 $       $Date: 2011/05/18 17:29:19 $
+ *      $Revision: 1.88 $       $Date: 2020/12/17 17:14:07 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -49,6 +49,7 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <stdlib.h>
+#include <stddef.h>
 #include <string.h>
 #include <math.h>
 #include <time.h>
@@ -56,6 +57,7 @@
 #include "molfile_plugin.h"
 #include "dcdplugin.h"
 
+
 /* print DCD error in a human readable way */
 static void print_dcderror(const char *func, int errcode) {
   const char *errstr;
@@ -103,6 +105,7 @@ static int read_dcdheader(fio_fd fd, int *N, int *NSET, int *ISTART,
   char hdrbuf[84];    /* char buffer used to store header */
   int NTITLE;
   int dcdcordmagic;
+  int hugefile = 0;
   char *corp = (char *) &dcdcordmagic;
 
   /* coordinate dcd file magic string 'CORD' */
@@ -123,30 +126,24 @@ static int read_dcdheader(fio_fd fd, int *N, int *NSET, int *ISTART,
   if ((input_integer[0]+input_integer[1]) == 84) {
     *reverseEndian=0;
     rec_scale=RECSCALE64BIT;
-    #ifdef DEBUG
     printf("dcdplugin) detected CHARMM -i8 64-bit DCD file of native endianness\n");
-    #endif
   } else if (input_integer[0] == 84 && input_integer[1] == dcdcordmagic) {
     *reverseEndian=0;
     rec_scale=RECSCALE32BIT;
-    #ifdef DEBUG
     printf("dcdplugin) detected standard 32-bit DCD file of native endianness\n");
-    #endif
   } else {
     /* now try reverse endian */
     swap4_aligned(input_integer, 2); /* will have to unswap magic if 32-bit */
     if ((input_integer[0]+input_integer[1]) == 84) {
       *reverseEndian=1;
       rec_scale=RECSCALE64BIT;
-      #ifdef DEBUG
       printf("dcdplugin) detected CHARMM -i8 64-bit DCD file of opposite endianness\n");
-      #endif
     } else {
       swap4_aligned(&input_integer[1], 1); /* unswap magic (see above) */
       if (input_integer[0] == 84 && input_integer[1] == dcdcordmagic) {
         *reverseEndian=1;
         rec_scale=RECSCALE32BIT;
-        /* printf("dcdplugin) detected standard 32-bit DCD file of opposite endianness\n"); */
+        printf("dcdplugin) detected standard 32-bit DCD file of opposite endianness\n");
       } else {
         /* not simply reversed endianism or -i8, something rather more evil */
         printf("dcdplugin) unrecognized DCD header:\n");
@@ -162,7 +159,7 @@ static int read_dcdheader(fio_fd fd, int *N, int *NSET, int *ISTART,
   if (rec_scale == RECSCALE64BIT) {
     ret_val = READ(fd, input_integer, sizeof(unsigned int));
     if (input_integer[0] != dcdcordmagic) {
-        /* printf("dcdplugin) failed to find CORD magic in CHARMM -i8 64-bit DCD file\n"); */
+      printf("dcdplugin) failed to find CORD magic in CHARMM -i8 64-bit DCD file\n");
       return DCD_BADFORMAT;
     }
   }
@@ -193,10 +190,10 @@ static int read_dcdheader(fio_fd fd, int *N, int *NSET, int *ISTART,
 
   if (*charmm & DCD_IS_CHARMM) {
     /* CHARMM and NAMD versions 2.1b1 and later */
-    /* printf("dcdplugin) CHARMM format DCD file (also NAMD 2.1 and later)\n"); */
+    printf("dcdplugin) CHARMM format DCD file (also NAMD 2.1 and later)\n");
   } else {
     /* CHARMM and NAMD versions prior to 2.1b1  */
-    /* printf("dcdplugin) X-PLOR format DCD file (also NAMD 2.0 and earlier)\n"); */
+    printf("dcdplugin) X-PLOR format DCD file (also NAMD 2.0 and earlier)\n");
   }
 
   /* Store the number of sets of coordinates (NSET) */
@@ -309,6 +306,14 @@ static int read_dcdheader(fio_fd fd, int *N, int *NSET, int *ISTART,
   CHECK_FEOF(ret_val, "reading number of atoms");
   if (*reverseEndian) swap4_aligned(N, 1);
 
+  if (*N > (1L<<30)) {
+    hugefile=1;
+    printf("dcdplugin) ***\n");
+    printf("dcdplugin) *** Trajectory contains over 2^30 atoms.\n");
+    printf("dcdplugin) *** Huge file integer wraparound handling enabled.\n");
+    printf("dcdplugin) ***\n");
+  }
+
   /* Read in an integer '4' */
   input_integer[1] = 0;
   ret_val = READ(fd, input_integer, rec_scale*sizeof(int));
@@ -323,11 +328,11 @@ static int read_dcdheader(fio_fd fd, int *N, int *NSET, int *ISTART,
   *FREEINDEXES = NULL;
   *fixedcoords = NULL;
   if (*NAMNF != 0) {
-    (*FREEINDEXES) = (int *) calloc(((*N)-(*NAMNF)), sizeof(int));
+    (*FREEINDEXES) = (int *) calloc((((ptrdiff_t)(*N))-(*NAMNF)), sizeof(int));
     if (*FREEINDEXES == NULL)
       return DCD_BADMALLOC;
 
-    *fixedcoords = (float *) calloc((*N)*4 - (*NAMNF), sizeof(float));
+    *fixedcoords = (float *) calloc(((ptrdiff_t)(*N))*4L - (*NAMNF), sizeof(float));
     if (*fixedcoords == NULL)
       return DCD_BADMALLOC;
 
@@ -338,11 +343,13 @@ static int read_dcdheader(fio_fd fd, int *N, int *NSET, int *ISTART,
     CHECK_FEOF(ret_val, "reading size of index array");
     if (*reverseEndian) swap4_aligned(input_integer, rec_scale);
 
-    if ((input_integer[0]+input_integer[1]) != ((*N)-(*NAMNF))*4) {
+    /* when we have more then 2^30 atoms, tests like this one */
+    /* are no longer meaningful and have to be bypassed...    */
+    if (!hugefile && ((input_integer[0]+input_integer[1]) != ((*N)-(*NAMNF))*4L)) {
       return DCD_BADFORMAT;
     }
 
-    ret_val = READ(fd, (*FREEINDEXES), ((*N)-(*NAMNF))*sizeof(int));
+    ret_val = READ(fd, (*FREEINDEXES), ((ptrdiff_t) ((*N)-(*NAMNF)))*sizeof(int));
     CHECK_FREAD(ret_val, "reading size of index array");
     CHECK_FEOF(ret_val, "reading size of index array");
 
@@ -355,7 +362,9 @@ static int read_dcdheader(fio_fd fd, int *N, int *NSET, int *ISTART,
     CHECK_FEOF(ret_val, "reading size of index array");
     if (*reverseEndian) swap4_aligned(input_integer, rec_scale);
 
-    if ((input_integer[0]+input_integer[1]) != ((*N)-(*NAMNF))*4) {
+    /* when we have more then 2^30 atoms, tests like this one */
+    /* are no longer meaningful and have to be bypassed...    */
+    if (!hugefile && ((input_integer[0]+input_integer[1]) != ((*N)-(*NAMNF))*4L)) {
       return DCD_BADFORMAT;
     }
   }
@@ -363,7 +372,9 @@ static int read_dcdheader(fio_fd fd, int *N, int *NSET, int *ISTART,
   return DCD_SUCCESS;
 }
 
-static int read_charmm_extrablock(fio_fd fd, int charmm, int reverseEndian, float *unitcell) {
+
+static int read_charmm_extrablock(fio_fd fd, int charmm, int reverseEndian,
+                                  float *unitcell) {
   int i, input_integer[2], rec_scale;
 
   if (charmm & DCD_HAS_64BIT_REC) {
@@ -394,10 +405,10 @@ static int read_charmm_extrablock(fio_fd fd, int charmm, int reverseEndian, floa
   return DCD_SUCCESS;
 }
 
+
 static int read_fixed_atoms(fio_fd fd, int N, int num_free, const int *indexes,
                             int reverseEndian, const float *fixedcoords,
-                            float *freeatoms, float *pos, int charmm)
-{
+                            float *freeatoms, float *pos, int charmm) {
   int i, input_integer[2], rec_scale;
 
   if(charmm & DCD_HAS_64BIT_REC) {
@@ -410,15 +421,15 @@ static int read_fixed_atoms(fio_fd fd, int N, int num_free, const int *indexes,
   input_integer[1]=0;
   if (fio_fread(input_integer, sizeof(int), rec_scale, fd) != rec_scale) return DCD_BADREAD;
   if (reverseEndian) swap4_aligned(input_integer, rec_scale);
-  if ((input_integer[0]+input_integer[1]) != 4*num_free) return DCD_BADFORMAT;
+  if ((input_integer[0]+input_integer[1]) != 4L*num_free) return DCD_BADFORMAT;
 
   /* Read free atom coordinates */
-  if (fio_fread(freeatoms, 4*num_free, 1, fd) != 1) return DCD_BADREAD;
+  if (fio_fread(freeatoms, 4L*num_free, 1, fd) != 1) return DCD_BADREAD;
   if (reverseEndian)
     swap4_aligned(freeatoms, num_free);
 
   /* Copy fixed and free atom coordinates into position buffer */
-  memcpy(pos, fixedcoords, 4*N);
+  memcpy(pos, fixedcoords, 4L*N);
   for (i=0; i<num_free; i++)
     pos[indexes[i]-1] = freeatoms[i];
 
@@ -426,13 +437,13 @@ static int read_fixed_atoms(fio_fd fd, int N, int num_free, const int *indexes,
   input_integer[1]=0;
   if (fio_fread(input_integer, sizeof(int), rec_scale, fd) != rec_scale) return DCD_BADREAD;
   if (reverseEndian) swap4_aligned(input_integer, rec_scale);
-  if ((input_integer[0]+input_integer[1]) != 4*num_free) return DCD_BADFORMAT;
+  if ((input_integer[0]+input_integer[1]) != 4L*num_free) return DCD_BADFORMAT;
 
   return DCD_SUCCESS;
 }
 
 static int read_charmm_4dim(fio_fd fd, int charmm, int reverseEndian) {
-  int input_integer[2],rec_scale;
+  int input_integer[2], rec_scale;
 
   if (charmm & DCD_HAS_64BIT_REC) {
     rec_scale=RECSCALE64BIT;
@@ -470,9 +481,15 @@ static int read_charmm_4dim(fio_fd fd, int charmm, int reverseEndian) {
 static int read_dcdstep(fio_fd fd, int N, float *X, float *Y, float *Z,
                         float *unitcell, int num_fixed,
                         int first, int *indexes, float *fixedcoords,
-                        int reverseEndian, int charmm)
-{
-  int ret_val, rec_scale;   /* Return value from read */
+                        int reverseEndian, int charmm) {
+  int ret_val;    /* Return value from read */
+  ptrdiff_t rec_scale;
+  int hugefile = (N > (1L<<30)) ? 1 : 0;
+  int check_reclen = 1; /* Enable Fortran record length value safety checks */
+
+  /* Fortran record length checks disabled for huge files or user request */
+  if (hugefile || (getenv("VMDDCDNOCHECKRECLEN") != NULL))
+    check_reclen = 0;
 
   if (charmm & DCD_HAS_64BIT_REC) {
     rec_scale=RECSCALE64BIT;
@@ -483,10 +500,9 @@ static int read_dcdstep(fio_fd fd, int N, float *X, float *Y, float *Z,
   if ((num_fixed==0) || first) {
     /* temp storage for reading formatting info */
     /* note: has to be max size we'll ever use  */
-    int tmpbuf[6*RECSCALEMAX];
+    int tmpbuf[6L*RECSCALEMAX];
 
     fio_iovec iov[7];   /* I/O vector for fio_readv() call          */
-    fio_size_t readlen; /* number of bytes actually read            */
     int i;
 
     /* if there are no fixed atoms or this is the first timestep read */
@@ -507,41 +523,68 @@ static int read_dcdstep(fio_fd fd, int N, float *X, float *Y, float *Z,
     iov[1].iov_len  = sizeof(float)*N;
 
     iov[2].iov_base = (fio_caddr_t) &tmpbuf[1*rec_scale]; /* read 2 format integers */
-    iov[2].iov_len  = rec_scale*sizeof(int) * 2;
+    iov[2].iov_len  = rec_scale*sizeof(int) * 2L;
 
     iov[3].iov_base = (fio_caddr_t) Y;          /* read Y coordinates     */
     iov[3].iov_len  = sizeof(float)*N;
 
-    iov[4].iov_base = (fio_caddr_t) &tmpbuf[3*rec_scale]; /* read 2 format integers */
-    iov[4].iov_len  = rec_scale*sizeof(int) * 2;
+    iov[4].iov_base = (fio_caddr_t) &tmpbuf[3L*rec_scale]; /* read 2 format integers */
+    iov[4].iov_len  = rec_scale*sizeof(int) * 2L;
 
     iov[5].iov_base = (fio_caddr_t) Z;          /* read Y coordinates     */
     iov[5].iov_len  = sizeof(float)*N;
 
-    iov[6].iov_base = (fio_caddr_t) &tmpbuf[5*rec_scale]; /* read format integer    */
+    iov[6].iov_base = (fio_caddr_t) &tmpbuf[5L*rec_scale]; /* read format integer    */
     iov[6].iov_len  = rec_scale*sizeof(int);
 
-    readlen = fio_readv(fd, &iov[0], 7);
+#if 1
+    /* Use fall-back code instead of readv():                            */
+    /*  Some platforms implement readv() as user level code in libc,     */
+    /*  and due to POSIX atomicity requirements for readv()/writev(),    */
+    /*  they may copy data to internal temp buffers, which can kill      */
+    /*  performance, and in cases when doing single I/O ops on large,    */
+    /*  buffers, e.g. > 2GB, can fail with shorts reads or writes...     */
+    /*  On such platforms it is best to avoid using readv()/writev()...  */
+    {
+      int readcnt = 0;
+      readcnt =  fio_fread(iov[0].iov_base, iov[0].iov_len, 1, fd);
+      readcnt += fio_fread(iov[1].iov_base, iov[1].iov_len, 1, fd);
+      readcnt += fio_fread(iov[2].iov_base, iov[2].iov_len, 1, fd);
+      readcnt += fio_fread(iov[3].iov_base, iov[3].iov_len, 1, fd);
+      readcnt += fio_fread(iov[4].iov_base, iov[4].iov_len, 1, fd);
+      readcnt += fio_fread(iov[5].iov_base, iov[5].iov_len, 1, fd);
+      readcnt += fio_fread(iov[6].iov_base, iov[6].iov_len, 1, fd);
 
-    if (readlen != (rec_scale*6*sizeof(int) + 3*N*sizeof(float)))
+      /* if all records read correctly, then the reads are okay */
+      if (readcnt != 7)
+        return DCD_BADREAD;
+    }
+#else
+    /* check number of bytes actually read            */
+    if (fio_readv(fd, &iov[0], 7) != ((fio_size_t) (rec_scale*6L*sizeof(int) + 3L*N*sizeof(float))))
       return DCD_BADREAD;
+#endif
 
     /* convert endianism if necessary */
     if (reverseEndian) {
-      swap4_aligned(&tmpbuf[0], rec_scale*6);
+      swap4_aligned(&tmpbuf[0], rec_scale*6L);
       swap4_aligned(X, N);
       swap4_aligned(Y, N);
       swap4_aligned(Z, N);
     }
 
-    /* double-check the fortran format size values for safety */
-    if(rec_scale == 1) {
-      for (i=0; i<6; i++) {
-        if (tmpbuf[i] != sizeof(float)*N) return DCD_BADFORMAT;
-      }
-    } else {
-      for (i=0; i<6; i++) {
-          if ((tmpbuf[2*i]+tmpbuf[2*i+1]) != sizeof(float)*N) return DCD_BADFORMAT;
+    /* when we have more then 2^30 atoms, tests like this one */
+    /* are no longer meaningful and have to be bypassed...    */
+    if (check_reclen) {
+      /* double-check the fortran format size values for safety */
+      if (rec_scale == 1) {
+        for (i=0; i<6; i++) {
+          if (tmpbuf[i] != sizeof(float)*N) return DCD_BADFORMAT;
+        }
+      } else {
+        for (i=0; i<6; i++) {
+          if ((tmpbuf[2L*i]+tmpbuf[2L*i+1L]) != sizeof(float)*N) return DCD_BADFORMAT;
+        }
       }
     }
 
@@ -550,7 +593,7 @@ static int read_dcdstep(fio_fd fd, int N, float *X, float *Y, float *Z,
     if (num_fixed && first) {
       memcpy(fixedcoords, X, N*sizeof(float));
       memcpy(fixedcoords+N, Y, N*sizeof(float));
-      memcpy(fixedcoords+2*N, Z, N*sizeof(float));
+      memcpy(fixedcoords+2L*N, Z, N*sizeof(float));
     }
 
     /* read in the optional charmm 4th array */
@@ -565,13 +608,13 @@ static int read_dcdstep(fio_fd fd, int N, float *X, float *Y, float *Z,
     ret_val = read_charmm_extrablock(fd, charmm, reverseEndian, unitcell);
     if (ret_val) return ret_val;
     ret_val = read_fixed_atoms(fd, N, N-num_fixed, indexes, reverseEndian,
-                               fixedcoords, fixedcoords+3*N, X, charmm);
+                               fixedcoords, fixedcoords+3L*N, X, charmm);
     if (ret_val) return ret_val;
     ret_val = read_fixed_atoms(fd, N, N-num_fixed, indexes, reverseEndian,
-                               fixedcoords+N, fixedcoords+3*N, Y, charmm);
+                               fixedcoords+N, fixedcoords+3L*N, Y, charmm);
     if (ret_val) return ret_val;
     ret_val = read_fixed_atoms(fd, N, N-num_fixed, indexes, reverseEndian,
-                               fixedcoords+2*N, fixedcoords+3*N, Z, charmm);
+                               fixedcoords+2*N, fixedcoords+3L*N, Z, charmm);
     if (ret_val) return ret_val;
     ret_val = read_charmm_4dim(fd, charmm, reverseEndian);
     if (ret_val) return ret_val;
@@ -593,9 +636,8 @@ static int read_dcdstep(fio_fd fd, int N, float *X, float *Y, float *Z,
  *               next timestep.
  */
 static int skip_dcdstep(fio_fd fd, int natoms, int nfixed, int charmm) {
-
-  int seekoffset = 0;
-  int rec_scale;
+  ptrdiff_t seekoffset = 0;
+  ptrdiff_t rec_scale;
 
   if (charmm & DCD_HAS_64BIT_REC) {
     rec_scale=RECSCALE64BIT;
@@ -605,15 +647,15 @@ static int skip_dcdstep(fio_fd fd, int natoms, int nfixed, int charmm) {
 
   /* Skip charmm extra block */
   if ((charmm & DCD_IS_CHARMM) && (charmm & DCD_HAS_EXTRA_BLOCK)) {
-    seekoffset += 4*rec_scale + 48 + 4*rec_scale;
+    seekoffset += 4L*rec_scale + 48L + 4L*rec_scale;
   }
 
   /* For each atom set, seek past an int, the free atoms, and another int. */
-  seekoffset += 3 * (2*rec_scale + natoms - nfixed) * 4;
+  seekoffset += 3L * (2L*rec_scale + natoms - nfixed) * 4L;
 
   /* Assume that charmm 4th dim is the same size as the other three. */
   if ((charmm & DCD_IS_CHARMM) && (charmm & DCD_HAS_4DIMS)) {
-    seekoffset += (2*rec_scale + natoms - nfixed) * 4;
+    seekoffset += (2L*rec_scale + natoms - nfixed) * 4L;
   }
 
   if (fio_fseek(fd, seekoffset, FIO_SEEK_CUR)) return DCD_BADEOF;
@@ -626,16 +668,15 @@ static int skip_dcdstep(fio_fd fd, int natoms, int nfixed, int charmm) {
  * Write a timestep to a dcd file
  * Input: fd - a file struct for which a dcd header has already been written
  *       curframe: Count of frames written to this file, starting with 1.
- *       curstep: Count of timesteps elapsed = istart + curframe * nsavc.
- *        natoms - number of elements in x, y, z arrays
+ *        curstep: Count of timesteps elapsed = istart + curframe * nsavc.
+ *         natoms: number of elements in x, y, z arrays
  *        x, y, z: pointers to atom coordinates
  * Output: 0 on success, negative error code on failure.
  * Side effects: coordinates are written to the dcd file.
  */
 static int write_dcdstep(fio_fd fd, int curframe, int curstep, int N,
                   const float *X, const float *Y, const float *Z,
-                  const double *unitcell, int charmm)
-{
+                  const double *unitcell, int charmm) {
   int out_integer;
 
   if (charmm) {
@@ -670,6 +711,7 @@ static int write_dcdstep(fio_fd fd, int curframe, int curstep, int N,
   return DCD_SUCCESS;
 }
 
+
 /*
  * Write a header for a new dcd file
  * Input: fd - file struct opened for binary writing
@@ -681,8 +723,7 @@ static int write_dcdstep(fio_fd fd, int curframe, int curstep, int N,
  */
 static int write_dcdheader(fio_fd fd, const char *remarks, int N,
                     int ISTART, int NSAVC, double DELTA, int with_unitcell,
-                    int charmm)
-{
+                    int charmm) {
   int out_integer;
   float out_float;
   char title_string[200];
@@ -737,12 +778,7 @@ static int write_dcdheader(fio_fd fd, const char *remarks, int N,
 
   cur_time=time(NULL);
   tmbuf=localtime(&cur_time);
-  /* This line segfaults under MSVC 2008. I don't know why. Replacinge */
-  /* it with a sprintf and asctime seems to acomplish the same goal */
-  /* and solve the problem. The final length of time_str will not buffer */
-  /* overflow in sprintf -- I checked the asctime docs make sure. RTM10/13/13 */
-  /*strftime(time_str, 80, "REMARKS Created %d %B, %Y at %R", tmbuf); */
-  sprintf(time_str, "REMARKS Created %s", asctime(tmbuf));
+  strftime(time_str, 80, "REMARKS Created %d %B, %Y at %R", tmbuf);
   WRITE(fd, time_str, 80);
 
   fio_write_int32(fd, 164);
@@ -784,7 +820,8 @@ int dcd_rewind(dcdhandle* dcd) {
     return 0;
 }
 
-dcdhandle* open_dcd_read(const char *path, const char *filetype, int *natoms, int* nsets) {
+dcdhandle* open_dcd_read(const char *path, const char *filetype,
+    int *natoms, int* nsets) {
   dcdhandle *dcd;
   fio_fd fd;
   int rc;
@@ -792,12 +829,14 @@ dcdhandle* open_dcd_read(const char *path, const char *filetype, int *natoms, in
 
   if (!path) return NULL;
 
+#if !(defined(_MSC_VER) && defined(FASTIO_NATIVEWIN32))
   /* See if the file exists, and get its size */
   memset(&stbuf, 0, sizeof(struct stat));
   if (stat(path, &stbuf)) {
     printf("dcdplugin) Could not access file '%s'.\n", path);
     return NULL;
   }
+#endif
 
   if (fio_open(path, FIO_READ, &fd) < 0) {
     printf("dcdplugin) Could not open file '%s' for reading.\n", path);
@@ -861,7 +900,10 @@ dcdhandle* open_dcd_read(const char *path, const char *filetype, int *natoms, in
     newnsets = trjsize / framesize + 1;
 
     if (dcd->nsets > 0 && newnsets != dcd->nsets) {
-      printf("dcdplugin) Warning: DCD header claims %d frames, file size indicates there are actually %d frames\n", dcd->nsets, newnsets);
+      printf("dcdplugin) Warning: DCD header claims %d frames, but \n"
+             "dcdplugin) file size (%ld) indicates there are actually \n"
+             "%d frames of size (%ld)\n",
+             dcd->nsets, trjsize, newnsets, framesize);
     }
 
     dcd->nsets = newnsets;
@@ -982,9 +1024,8 @@ void close_file_read(dcdhandle *v) {
 }
 
 
-dcdhandle* open_dcd_write(const char *path, const char *filetype, const int natoms,
-                          const int with_unitcell)
-    {
+dcdhandle* open_dcd_write(const char *path, const char *filetype,
+    const int natoms, const int with_unitcell) {
   dcdhandle *dcd;
   fio_fd fd;
   int rc;
@@ -1005,7 +1046,12 @@ dcdhandle* open_dcd_write(const char *path, const char *filetype, const int nato
   nsavc = 1;              /* number of timesteps between written DCD frames */
   delta = 1.0;            /* length of a timestep                           */
 
-  charmm = DCD_IS_CHARMM; /* charmm-formatted DCD file                */
+  /* Always use CHARMM formatted DCD file.
+     Original VMD code uses an environment variable to determine format (and
+     also the with_unitcell parameter) but we will always use the CHARMM
+     format and allow the caller to specify with_unitcell
+  */
+  charmm = DCD_IS_CHARMM;
   if (with_unitcell)
       charmm |= DCD_HAS_EXTRA_BLOCK;
 
