@@ -1,5 +1,5 @@
-"""gro.py: Used for loading Gromacs GRO files.
-"""
+"""gro.py: Used for loading Gromacs GRO files."""
+
 ##############################################################################
 # MDTraj: A Python Library for Loading, Saving, and Manipulating
 #         Molecular Dynamics Trajectories.
@@ -44,31 +44,21 @@
 # USE OR OTHER DEALINGS IN THE SOFTWARE.
 ##############################################################################
 
-##############################################################################
-# Imports
-##############################################################################
-
-
-import os
-import sys
 import itertools
-from re import sub, match, findall
-# import element as elem
-import numpy as np
+import os
 import warnings
+from re import findall, match, sub
+
+import numpy as np
 
 import mdtraj as md
-from mdtraj.utils import in_units_of, cast_indices, ensure_type
-from mdtraj.formats import pdb
 from mdtraj.core import element as elem
+from mdtraj.formats import pdb
 from mdtraj.formats.registry import FormatRegistry
+from mdtraj.utils import cast_indices, ensure_type, in_units_of
 
 
-##############################################################################
-# Code
-##############################################################################
-
-@FormatRegistry.register_loader('.gro')
+@FormatRegistry.register_loader(".gro")
 def load_gro(filename, stride=None, atom_indices=None, frame=None, top=None):
     """Load a GROMACS GRO file.
 
@@ -89,21 +79,22 @@ def load_gro(filename, stride=None, atom_indices=None, frame=None, top=None):
         if you give a topology as input the topology won't be parsed from the gro file
         it saves time if you have to parse a big number of files
     """
-    from mdtraj.core.trajectory import _parse_topology, Trajectory
 
-    with GroTrajectoryFile(filename, 'r', top=top) as f:
-        topology = f.topology
+    with GroTrajectoryFile(filename, "r", top=top) as f:
         if frame is not None:
             f.seek(frame)
             n_frames = 1
         else:
             n_frames = None
-        return f.read_as_traj(n_frames=n_frames, stride=stride,
-                              atom_indices=atom_indices)
+        return f.read_as_traj(
+            n_frames=n_frames,
+            stride=stride,
+            atom_indices=atom_indices,
+        )
 
 
-@FormatRegistry.register_fileobject('.gro')
-class GroTrajectoryFile(object):
+@FormatRegistry.register_fileobject(".gro")
+class GroTrajectoryFile:
     """Interface for reading and writing to GROMACS GRO files.
 
     Parameters
@@ -130,19 +121,20 @@ class GroTrajectoryFile(object):
     --------
     load_gro : High-level wrapper that returns a ``md.Trajectory``
     """
-    distance_unit = 'nanometers'
 
-    def __init__(self, filename, mode='r', force_overwrite=True, top=None):
+    distance_unit = "nanometers"
+
+    def __init__(self, filename, mode="r", force_overwrite=True, top=None):
         self._open = False
         self._file = None
         self._mode = mode
 
         self.topology = top
 
-        if mode == 'r':
+        if mode == "r":
             self._open = True
             self._frame_index = 0
-            self._file = open(filename, 'r')
+            self._file = open(filename)
             try:
                 if self.topology is None:
                     self.n_atoms, self.topology = self._read_topology()
@@ -150,18 +142,23 @@ class GroTrajectoryFile(object):
                     self.n_atoms = self.topology.n_atoms
             finally:
                 self._file.seek(0)
-        elif mode == 'w':
+        elif mode == "w":
             self._open = True
             if os.path.exists(filename) and not force_overwrite:
-                raise IOError('"%s" already exists' % filename)
+                raise OSError('"%s" already exists' % filename)
             self._frame_index = 0
-            self._file = open(filename, 'w')
+            self._file = open(filename, "w")
         else:
             raise ValueError("invalid mode: %s" % mode)
 
-
-    def write(self, coordinates, topology, time=None, unitcell_vectors=None,
-              precision=3):
+    def write(
+        self,
+        coordinates,
+        topology,
+        time=None,
+        unitcell_vectors=None,
+        precision=3,
+    ):
         """Write one or more frames of a molecular dynamics trajectory to disk
         in the GROMACS GRO format.
 
@@ -180,19 +177,47 @@ class GroTrajectoryFile(object):
             The number of decimal places to print for coordinates. Default is 3
         """
         if not self._open:
-            raise ValueError('I/O operation on closed file')
-        if not self._mode == 'w':
-            raise ValueError('file not opened for writing')
+            raise ValueError("I/O operation on closed file")
+        if not self._mode == "w":
+            raise ValueError("file not opened for writing")
 
-        coordinates = ensure_type(coordinates, dtype=np.float32, ndim=3, name='coordinates', can_be_none=False, warn_on_cast=False)
-        time = ensure_type(time, dtype=float, ndim=1, name='time', can_be_none=True, shape=(len(coordinates),), warn_on_cast=False)
-        unitcell_vectors = ensure_type(unitcell_vectors, dtype=float, ndim=3, name='unitcell_vectors',
-            can_be_none=True, shape=(len(coordinates), 3, 3), warn_on_cast=False)
+        coordinates = ensure_type(
+            coordinates,
+            dtype=np.float32,
+            ndim=3,
+            name="coordinates",
+            can_be_none=False,
+            warn_on_cast=False,
+        )
+        time = ensure_type(
+            time,
+            dtype=float,
+            ndim=1,
+            name="time",
+            can_be_none=True,
+            shape=(len(coordinates),),
+            warn_on_cast=False,
+        )
+        unitcell_vectors = ensure_type(
+            unitcell_vectors,
+            dtype=float,
+            ndim=3,
+            name="unitcell_vectors",
+            can_be_none=True,
+            shape=(len(coordinates), 3, 3),
+            warn_on_cast=False,
+        )
 
         for i in range(coordinates.shape[0]):
             frame_time = None if time is None else time[i]
             frame_box = None if unitcell_vectors is None else unitcell_vectors[i]
-            self._write_frame(coordinates[i], topology, frame_time, frame_box, precision)
+            self._write_frame(
+                coordinates[i],
+                topology,
+                frame_time,
+                frame_box,
+                precision,
+            )
 
     def read_as_traj(self, n_frames=None, stride=None, atom_indices=None):
         """Read a trajectory from a gro file
@@ -215,22 +240,35 @@ class GroTrajectoryFile(object):
             A trajectory object containing the loaded portion of the file.
         """
         from mdtraj.core.trajectory import Trajectory
+
         topology = self.topology
         if atom_indices is not None:
             topology = topology.subset(atom_indices)
 
-        coordinates, time, unitcell_vectors = self.read(stride=stride, atom_indices=atom_indices)
+        coordinates, time, unitcell_vectors = self.read(
+            stride=stride,
+            atom_indices=atom_indices,
+        )
         if len(coordinates) == 0:
             return Trajectory(xyz=np.zeros((0, topology.n_atoms, 3)), topology=topology)
 
-        coordinates = in_units_of(coordinates, self.distance_unit, Trajectory._distance_unit, inplace=True)
-        unitcell_vectors = in_units_of(unitcell_vectors, self.distance_unit, Trajectory._distance_unit, inplace=True)
+        coordinates = in_units_of(
+            coordinates,
+            self.distance_unit,
+            Trajectory._distance_unit,
+            inplace=True,
+        )
+        unitcell_vectors = in_units_of(
+            unitcell_vectors,
+            self.distance_unit,
+            Trajectory._distance_unit,
+            inplace=True,
+        )
 
         traj = Trajectory(xyz=coordinates, topology=topology, time=time)
         traj.unitcell_vectors = unitcell_vectors
         return traj
 
-
     def read(self, n_frames=None, stride=None, atom_indices=None):
         """Read data from a molecular dynamics trajectory in the GROMACS GRO
         format.
@@ -257,9 +295,9 @@ class GroTrajectoryFile(object):
             The box vectors in each frame, in units of nanometers
         """
         if not self._open:
-            raise ValueError('I/O operation on closed file')
-        if not self._mode == 'r':
-            raise ValueError('file not opened for reading')
+            raise ValueError("I/O operation on closed file")
+        if not self._mode == "r":
+            raise ValueError("file not opened for reading")
 
         coordinates = []
         unitcell_vectors = []
@@ -284,7 +322,10 @@ class GroTrajectoryFile(object):
             except StopIteration:
                 break
 
-        coordinates, unitcell_vectors, time = map(np.array, (coordinates, unitcell_vectors, time))
+        coordinates, unitcell_vectors, time = map(
+            np.array,
+            (coordinates, unitcell_vectors, time),
+        )
 
         if not contains_time:
             time = None
@@ -295,9 +336,9 @@ class GroTrajectoryFile(object):
 
     def _read_topology(self):
         if not self._open:
-            raise ValueError('I/O operation on closed file')
-        if not self._mode == 'r':
-            raise ValueError('file not opened for reading')
+            raise ValueError("I/O operation on closed file")
+        if not self._mode == "r":
+            raise ValueError("file not opened for reading")
         pdb.PDBTrajectoryFile._loadNameReplacementTables()
 
         n_atoms = None
@@ -314,16 +355,23 @@ class GroTrajectoryFile(object):
             if ln == 1:
                 n_atoms = int(line.strip())
             elif ln > 1 and ln < n_atoms + 2:
-                (thisresnum, thisresname, thisatomname, thisatomnum) = \
-                    [line[i*5:i*5+5].strip() for i in range(4)]
+                (thisresnum, thisresname, thisatomname, thisatomnum) = (
+                    line[i * 5 : i * 5 + 5].strip() for i in range(4)
+                )
                 thisresnum, thisatomnum = map(int, (thisresnum, thisatomnum))
                 if residue is None or residue.resSeq != thisresnum or old_resname != thisresname:
                     if residue is not None and thisresnum == residue.resSeq:
-                        warnings.warn("WARNING: two consecutive residues with same number (%s, %s)" % (thisresname, old_resname))
+                        warnings.warn(
+                            f"WARNING: two consecutive residues with same number ({thisresname}, {old_resname})",
+                        )
                     old_resname = thisresname
                     if thisresname in pdb.PDBTrajectoryFile._residueNameReplacements:
                         thisresname = pdb.PDBTrajectoryFile._residueNameReplacements[thisresname]
-                    residue = topology.add_residue(thisresname, chain, resSeq=thisresnum)
+                    residue = topology.add_residue(
+                        thisresname,
+                        chain,
+                        resSeq=thisresnum,
+                    )
                     if thisresname in pdb.PDBTrajectoryFile._atomNameReplacements:
                         atomReplacements = pdb.PDBTrajectoryFile._atomNameReplacements[thisresname]
                     else:
@@ -331,7 +379,7 @@ class GroTrajectoryFile(object):
 
                 thiselem = thisatomname
                 if len(thiselem) > 1:
-                    thiselem = thiselem[0] + sub('[A-Z0-9]','',thiselem[1:])
+                    thiselem = thiselem[0] + sub("[A-Z0-9]", "", thiselem[1:])
                 try:
                     element = elem.get_by_symbol(thiselem)
                 except KeyError:
@@ -339,21 +387,25 @@ class GroTrajectoryFile(object):
                 if thisatomname in atomReplacements:
                     thisatomname = atomReplacements[thisatomname]
 
-                topology.add_atom(thisatomname, element=element, residue=residue,
-                                  serial=thisatomnum)
+                topology.add_atom(
+                    thisatomname,
+                    element=element,
+                    residue=residue,
+                    serial=thisatomnum,
+                )
         topology.create_standard_bonds()
         return n_atoms, topology
 
     def _read_frame(self):
         if not self._open:
-            raise ValueError('I/O operation on closed file')
-        if not self._mode == 'r':
-            raise ValueError('file not opened for reading')
+            raise ValueError("I/O operation on closed file")
+        if not self._mode == "r":
+            raise ValueError("file not opened for reading")
 
         atomcounter = itertools.count()
         comment = None
         boxvectors = None
-        topology = None
+
         xyz = np.zeros((self.n_atoms, 3), dtype=np.float32)
 
         got_line = False
@@ -369,8 +421,8 @@ class GroTrajectoryFile(object):
                 continue
             if firstDecimalPos is None:
                 try:
-                    firstDecimalPos = line.index('.', 20)
-                    secondDecimalPos = line.index('.', firstDecimalPos+1)
+                    firstDecimalPos = line.index(".", 20)
+                    secondDecimalPos = line.index(".", firstDecimalPos + 1)
                 except ValueError:
                     firstDecimalPos = secondDecimalPos = None
             crd = _parse_gro_coord(line, firstDecimalPos, secondDecimalPos)
@@ -383,39 +435,48 @@ class GroTrajectoryFile(object):
                 # the gro_box line comes at the end of the record
                 break
             else:
-                raise Exception("Unexpected line in .gro file: "+line)
+                raise Exception("Unexpected line in .gro file: " + line)
 
         if not got_line:
             raise StopIteration()
 
         time = None
-        if 't=' in comment:
+        if "t=" in comment:
             # title string (free format string, optional time in ps after 't=')
-            time = float(findall('t= *(\d+\.\d+)',comment)[-1])
+            time = float(findall(r"t= *(\d+\.\d+)", comment)[-1])
 
         # box vectors (free format, space separated reals), values: v1(x) v2(y)
         # v3(z) v1(y) v1(z) v2(x) v2(z) v3(x) v3(y), the last 6 values may be
         # omitted (they will be set to zero).
         box = [boxvectors[i] if i < len(boxvectors) else 0 for i in range(9)]
-        unitcell_vectors = np.array([
-            [box[0], box[3], box[4]],
-            [box[5], box[1], box[6]],
-            [box[7], box[8], box[2]]])
+        unitcell_vectors = np.array(
+            [
+                [box[0], box[3], box[4]],
+                [box[5], box[1], box[6]],
+                [box[7], box[8], box[2]],
+            ],
+        )
 
         return xyz, unitcell_vectors, time
 
     def _write_frame(self, coordinates, topology, time, box, precision):
-        comment = 'Generated with MDTraj'
+        comment = "Generated with MDTraj"
         if time is not None:
-            comment += ', t= %s' % time
+            comment += ", t= %s" % time
 
         varwidth = precision + 5
-        fmt = '%%5d%%-5s%%5s%%5d%%%d.%df%%%d.%df%%%d.%df' % (
-                varwidth, precision, varwidth, precision, varwidth, precision)
+        fmt = "%%5d%%-5s%%5s%%5d%%%d.%df%%%d.%df%%%d.%df" % (
+            varwidth,
+            precision,
+            varwidth,
+            precision,
+            varwidth,
+            precision,
+        )
         assert topology.n_atoms == coordinates.shape[0]
-        lines = [comment, ' %d' % topology.n_atoms]
+        lines = [comment, " %d" % topology.n_atoms]
         if box is None:
-            box = np.zeros((3,3))
+            box = np.zeros((3, 3))
 
         for i in range(topology.n_atoms):
             atom = topology.atom(i)
@@ -425,16 +486,27 @@ class GroTrajectoryFile(object):
                 serial = atom.index
             if serial >= 100000:
                 serial %= 100000
-            lines.append(fmt % (residue.resSeq, residue.name, atom.name, serial,
-                                coordinates[i, 0], coordinates[i, 1], coordinates[i, 2]))
+            lines.append(
+                fmt
+                % (
+                    residue.resSeq,
+                    residue.name,
+                    atom.name,
+                    serial,
+                    coordinates[i, 0],
+                    coordinates[i, 1],
+                    coordinates[i, 2],
+                ),
+            )
 
-        lines.append('%10.5f%10.5f%10.5f%10.5f%10.5f%10.5f%10.5f%10.5f%10.5f' % (
-            box[0,0], box[1,1], box[2,2],
-            box[0,1], box[0,2], box[1,0],
-            box[1,2], box[2,0], box[2,1]))
+        lines.append(
+            f"{box[0, 0]:10.5f}{box[1, 1]:10.5f}{box[2, 2]:10.5f}"
+            f"{box[0, 1]:10.5f}{box[0, 2]:10.5f}{box[1, 0]:10.5f}"
+            f"{box[1, 2]:10.5f}{box[2, 0]:10.5f}{box[2, 1]:10.5f}",
+        )
 
-        self._file.write('\n'.join(lines))
-        self._file.write('\n')
+        self._file.write("\n".join(lines))
+        self._file.write("\n")
 
     def seek(self, offset, whence=0):
         """Move to a new file position
@@ -475,10 +547,6 @@ class GroTrajectoryFile(object):
         "Support the context manager protocol"
         self.close()
 
-##############################################################################
-# Utilities
-##############################################################################
-
 
 def _isint(word):
     """ONLY matches integers! If you have a decimal point? None shall pass!
@@ -487,7 +555,8 @@ def _isint(word):
     @return answer Boolean which specifies whether the string is an integer (only +/- sign followed by digits)
 
     """
-    return match('^[-+]?[0-9]+$',word)
+    return match("^[-+]?[0-9]+$", word)
+
 
 def _isfloat(word):
     """Matches ANY number; it can be a decimal, scientific notation, what have you
@@ -497,10 +566,11 @@ def _isfloat(word):
     @return answer Boolean which specifies whether the string is any number
 
     """
-    return match('^[-+]?[0-9]*\.?[0-9]*([eEdD][-+]?[0-9]+)?$',word)
+    return match(r"^[-+]?[0-9]*\.?[0-9]*([eEdD][-+]?[0-9]+)?$", word)
+
 
 def _parse_gro_coord(line, firstDecimal, secondDecimal):
-    """ Determines whether a line contains GROMACS data or not
+    """Determines whether a line contains GROMACS data or not
 
     @param[in] line The line to be tested
 
@@ -509,12 +579,13 @@ def _parse_gro_coord(line, firstDecimal, secondDecimal):
         return None
     digits = secondDecimal - firstDecimal
     try:
-        return tuple(float(line[20+i*digits:20+(i+1)*digits]) for i in range(3))
+        return tuple(float(line[20 + i * digits : 20 + (i + 1) * digits]) for i in range(3))
     except ValueError:
         return None
 
+
 def _is_gro_box(line):
-    """ Determines whether a line contains a GROMACS box vector or not
+    """Determines whether a line contains a GROMACS box vector or not
 
     @param[in] line The line to be tested
 
