@@ -20,53 +20,52 @@
 # License along with MDTraj. If not, see <http://www.gnu.org/licenses/>.
 ##############################################################################
 
-""" MSMBuilder2 "LH5" trajectory format.
-"""
+"""MSMBuilder2 "LH5" trajectory format."""
 
 ##############################################################################
 # Imports
 ##############################################################################
 
-from __future__ import print_function, division
 import os
 import sys
-import numpy as np
-from mdtraj.core import element as elem
-from mdtraj.utils.six import iteritems, PY3, u
-from mdtraj.formats.registry import FormatRegistry
-from mdtraj.utils import import_, ensure_type, in_units_of, cast_indices
-from mdtraj.formats.hdf5 import _check_mode
 import warnings
 
+import numpy as np
+
+from mdtraj.core import element as elem
+from mdtraj.formats.hdf5 import _check_mode
+from mdtraj.formats.registry import FormatRegistry
+from mdtraj.utils import cast_indices, ensure_type, import_, in_units_of
+
 MAXINT16 = np.iinfo(np.int16).max
 MAXINT32 = np.iinfo(np.int32).max
 DEFAULT_PRECISION = 1000
-if PY3:
-    basestring = str
 
-__all__ = ['LH5TrajectoryFile', 'load_lh5']
+__all__ = ["LH5TrajectoryFile", "load_lh5"]
 
 ##############################################################################
 # Utilities
 ##############################################################################
 
+
 def _topology_from_arrays(AtomID, AtomNames, ChainID, ResidueID, ResidueNames):
     """Build topology object from the arrays stored in the lh5 file"""
     # Delayed import due to wacky recursive imports in compatibilty
     from mdtraj import Topology
+
     topology = Topology()
 
     # assert that the ChainID is just an array of empty strings, which appears
     # to be the case in our test systems for this legacy format
-    if not np.all(chainid == '' for chainid in ChainID):
-        raise NotImplementedError('Im not prepared to parse multiple chains')
+    if not np.all(chainid == "" for chainid in ChainID):
+        raise NotImplementedError("Im not prepared to parse multiple chains")
     chain0 = topology.add_chain()
 
     # register the residues
     registered_residues = {}
     for i in np.argsort(ResidueID):
         residue_name = ResidueNames[i]
-        if not isinstance(residue_name, basestring):
+        if not isinstance(residue_name, str):
             residue_name = residue_name.decode()
         if ResidueID[i] not in registered_residues:
             res = topology.add_residue(residue_name, chain0)
@@ -75,17 +74,20 @@ def _topology_from_arrays(AtomID, AtomNames, ChainID, ResidueID, ResidueNames):
     # register the atoms
     for i in np.argsort(AtomID):
         atom_name = AtomNames[i]
-        if not isinstance(atom_name, basestring):
+        if not isinstance(atom_name, str):
             atom_name = atom_name.decode()
-        element_symbol = atom_name.lstrip('0123456789')[0]
+        element_symbol = atom_name.lstrip("0123456789")[0]
 
         try:
             element = elem.get_by_symbol(element_symbol)
         except KeyError:
             element = elem.virtual
 
-        topology.add_atom(atom_name, element,
-                          registered_residues[ResidueID[i]])
+        topology.add_atom(
+            atom_name,
+            element,
+            registered_residues[ResidueID[i]],
+        )
 
     topology.create_standard_bonds()
     return topology
@@ -100,15 +102,21 @@ def _convert_from_lossy_integers(X, precision=DEFAULT_PRECISION):
 
 
 def _convert_to_lossy_integers(X, precision=DEFAULT_PRECISION):
-    """Implementation of the lossy compression used in Gromacs XTC using the pytables library.  Convert 32 bit floats into 16 bit integers.  These conversion functions have been optimized for memory use.  Further memory reduction would require an in-place astype() operation, which one could create using ctypes."""
+    """
+    Implementation of the lossy compression used in Gromacs XTC using the pytables library.  Convert 32 bit floats
+    into 16 bit integers.  These conversion functions have been optimized for memory use.  Further memory reduction
+    would require an in-place astype() operation, which one could create using ctypes.
+    """
     if np.max(X) * float(precision) < MAXINT16 and np.min(X) * float(precision) > -MAXINT16:
         X *= float(precision)
         Rounded = X.astype("int16")
         X /= float(precision)
     else:
-        raise ValueError("Data range too large for lh5. Try removing center of "
-                         "mass motion, check for 'blowing up, or use a different "
-                         "trajectory format")
+        raise ValueError(
+            "Data range too large for lh5. Try removing center of "
+            "mass motion, check for 'blowing up, or use a different "
+            "trajectory format",
+        )
     return Rounded
 
 
@@ -116,7 +124,8 @@ def _convert_to_lossy_integers(X, precision=DEFAULT_PRECISION):
 # Main code
 ##############################################################################
 
-@FormatRegistry.register_loader('.lh5')
+
+@FormatRegistry.register_loader(".lh5")
 def load_lh5(filename, top=None, stride=None, atom_indices=None, frame=None):
     """Load an deprecated MSMBuilder2 LH5 trajectory file.
 
@@ -150,11 +159,15 @@ def load_lh5(filename, top=None, stride=None, atom_indices=None, frame=None):
             n_frames = 1
         else:
             n_frames = None
-        return f.read_as_traj(n_frames=n_frames, stride=stride, atom_indices=atom_indices)
+        return f.read_as_traj(
+            n_frames=n_frames,
+            stride=stride,
+            atom_indices=atom_indices,
+        )
 
 
-@FormatRegistry.register_fileobject('.lh5')
-class LH5TrajectoryFile(object):
+@FormatRegistry.register_fileobject(".lh5")
+class LH5TrajectoryFile:
     """Interface for reading and writing to a MSMBuilder2 "LH5" molecular
     dynamics trajectory file, a deprecated format.
 
@@ -169,27 +182,27 @@ class LH5TrajectoryFile(object):
         In mode='w', how do you want to behave if a file by the name of `filename`
         already exists? if `force_overwrite=True`, it will be overwritten.
     """
-    distance_unit = 'nanometers'
 
+    distance_unit = "nanometers"
 
-    def __init__(self, filename, mode='r', force_overwrite=True):
+    def __init__(self, filename, mode="r", force_overwrite=True):
         self._open = False
         self.filename = filename
         self.mode = mode
-        if mode == 'w' and not force_overwrite and os.path.exists(filename):
-            raise IOError('"%s" already exists' % filename)
+        if mode == "w" and not force_overwrite and os.path.exists(filename):
+            raise OSError('"%s" already exists' % filename)
         # import tables
-        self.tables = import_('tables')
+        self.tables = import_("tables")
 
-        if mode == 'w':
+        if mode == "w":
             print("Warning: The LH5 trajectory format is deprecated.", file=sys.stderr)
             # what frame are we currently reading or writing at?
             self._frame_index = 0
             # do we need to write the header information?
             self._needs_initialization = True
-            if not os.fspath(filename).endswith('.lh5'):
-                warnings.warn('The .lh5 extension is recommended.')
-        elif mode == 'r':
+            if not os.fspath(filename).endswith(".lh5"):
+                warnings.warn("The .lh5 extension is recommended.")
+        elif mode == "r":
             self._frame_index = 0
             self._needs_initialization = False
         else:
@@ -197,9 +210,15 @@ class LH5TrajectoryFile(object):
 
         # Compression style of legacy MSMBuilder2 lh5 trajectory format
         compression = self.tables.Filters(
-            complib='blosc', shuffle=True, complevel=1)
+            complib="blosc",
+            shuffle=True,
+            complevel=1,
+        )
         self._handle = self._open_file(
-            filename, mode=mode, filters=compression)
+            filename,
+            mode=mode,
+            filters=compression,
+        )
         self._open = True
 
     @property
@@ -211,14 +230,18 @@ class LH5TrajectoryFile(object):
         topology : mdtraj.Topology
             A topology object
         """
-        if np.all(self._handle.root.AtomID[:] == 0) and (np.all(self._handle.root.AtomNames[:] == b'')
-            or np.all(self._handle.root.eAtomNames[:] == u(''))):
+        if np.all(self._handle.root.AtomID[:] == 0) and (
+            np.all(self._handle.root.AtomNames[:] == b"") or np.all(self._handle.root.eAtomNames[:] == "")
+        ):
             return None
 
         return _topology_from_arrays(
-            self._handle.root.AtomID[:], self._handle.root.AtomNames[:],
-            self._handle.root.ChainID[:], self._handle.root.ResidueID[:],
-            self._handle.root.ResidueNames[:])
+            self._handle.root.AtomID[:],
+            self._handle.root.AtomNames[:],
+            self._handle.root.ChainID[:],
+            self._handle.root.ResidueID[:],
+            self._handle.root.ResidueNames[:],
+        )
 
     @topology.setter
     def topology(self, top):
@@ -229,7 +252,7 @@ class LH5TrajectoryFile(object):
         top : mdtraj.Topology
             A topology object
         """
-        _check_mode(self.mode, ('w',))
+        _check_mode(self.mode, ("w",))
 
         if self._needs_initialization:
             self._initialize_headers(top.n_atoms)
@@ -244,8 +267,8 @@ class LH5TrajectoryFile(object):
             "ChainID": top.chainID.values,
             "ResidueID": top.resSeq.values + 1,
         }
-        for key, val in iteritems(data):
-            node = self._get_node(where='/', name=key)[:] = val[:]
+        for key, val in data.items():
+            node = self._get_node(where="/", name=key)[:] = val[:]
             node[:] = val[:]
 
     def read_as_traj(self, n_frames=None, stride=None, atom_indices=None):
@@ -272,9 +295,10 @@ class LH5TrajectoryFile(object):
         trajectory : Trajectory
             A trajectory object containing the loaded portion of the file.
         """
-        _check_mode(self.mode, ('r',))
+        _check_mode(self.mode, ("r",))
 
         from mdtraj.core.trajectory import Trajectory
+
         topology = self.topology
         if atom_indices is not None:
             topology = topology.subset(atom_indices)
@@ -287,7 +311,7 @@ class LH5TrajectoryFile(object):
         in_units_of(xyz, self.distance_unit, Trajectory._distance_unit, inplace=True)
         if stride is None:
             stride = 1
-        time = (stride*np.arange(len(xyz))) + initial
+        time = (stride * np.arange(len(xyz))) + initial
 
         return Trajectory(xyz=xyz, topology=topology, time=time)
 
@@ -315,7 +339,7 @@ class LH5TrajectoryFile(object):
         xyz : np.ndarray, shape=(n_frames, n_atoms, 3), dtype=np.float32
             The cartesian coordinates, in nanometers
         """
-        _check_mode(self.mode, ('r'))
+        _check_mode(self.mode, ("r"))
 
         if n_frames is None:
             n_frames = np.inf
@@ -324,12 +348,23 @@ class LH5TrajectoryFile(object):
         if atom_indices is None:
             atom_slice = slice(None)
         else:
-            atom_slice = ensure_type(atom_indices, dtype=int, ndim=1,
-                                     name='atom_indices', warn_on_cast=False)
+            atom_slice = ensure_type(
+                atom_indices,
+                dtype=int,
+                ndim=1,
+                name="atom_indices",
+                warn_on_cast=False,
+            )
 
         total_n_frames = len(self._handle.root.XYZList)
-        frame_slice = slice(self._frame_index, min(
-            self._frame_index + n_frames, total_n_frames), stride)
+        frame_slice = slice(
+            self._frame_index,
+            min(
+                self._frame_index + n_frames,
+                total_n_frames,
+            ),
+            stride,
+        )
         if frame_slice.stop - frame_slice.start == 0:
             return np.array([], dtype=np.float32)
 
@@ -337,7 +372,7 @@ class LH5TrajectoryFile(object):
         if xyz.dtype == np.int16 or xyz.dtype == np.int32:
             xyz = _convert_from_lossy_integers(xyz)
 
-        self._frame_index += (frame_slice.stop - frame_slice.start)
+        self._frame_index += frame_slice.stop - frame_slice.start
         return xyz
 
     def write(self, coordinates):
@@ -348,37 +383,64 @@ class LH5TrajectoryFile(object):
         coordinates : np.ndarray, dtype=np.float32, shape=(n_frames, n_atoms, 3)
             The cartesian coordinates of the atoms in every frame, in nanometers.
         """
-        _check_mode(self.mode, ('w'))
+        _check_mode(self.mode, ("w"))
 
-        coordinates = ensure_type(coordinates, dtype=np.float32, ndim=3,
-                                  name='coordinates', shape=(None, None, 3), can_be_none=False,
-                                  warn_on_cast=False, add_newaxis_on_deficient_ndim=True)
+        coordinates = ensure_type(
+            coordinates,
+            dtype=np.float32,
+            ndim=3,
+            name="coordinates",
+            shape=(None, None, 3),
+            can_be_none=False,
+            warn_on_cast=False,
+            add_newaxis_on_deficient_ndim=True,
+        )
         if self._needs_initialization:
             self._initialize_headers(coordinates.shape[1])
             self._needs_initialization = False
 
         coordinates = _convert_to_lossy_integers(coordinates)
-        self._get_node(where='/', name='XYZList').append(coordinates)
+        self._get_node(where="/", name="XYZList").append(coordinates)
 
     def _initialize_headers(self, n_atoms):
-        _check_mode(self.mode, ('w'))
+        _check_mode(self.mode, ("w"))
 
         self._create_carray(
-            where='/', name='AtomID', atom=self.tables.Int64Atom(), shape=(n_atoms,))
+            where="/",
+            name="AtomID",
+            atom=self.tables.Int64Atom(),
+            shape=(n_atoms,),
+        )
         self._create_carray(
-            where='/', name='AtomNames', atom=self.tables.StringAtom(itemsize=4),
-            shape=(n_atoms,))
+            where="/",
+            name="AtomNames",
+            atom=self.tables.StringAtom(itemsize=4),
+            shape=(n_atoms,),
+        )
         self._create_carray(
-            where='/', name='ResidueNames', atom=self.tables.StringAtom(itemsize=4),
-            shape=(n_atoms,))
+            where="/",
+            name="ResidueNames",
+            atom=self.tables.StringAtom(itemsize=4),
+            shape=(n_atoms,),
+        )
         self._create_carray(
-            where='/', name='ChainID', atom=self.tables.StringAtom(itemsize=1),
-            shape=(n_atoms,))
+            where="/",
+            name="ChainID",
+            atom=self.tables.StringAtom(itemsize=1),
+            shape=(n_atoms,),
+        )
         self._create_carray(
-            where='/', name='ResidueID', atom=self.tables.Int64Atom(), shape=(n_atoms,))
+            where="/",
+            name="ResidueID",
+            atom=self.tables.Int64Atom(),
+            shape=(n_atoms,),
+        )
         self._create_earray(
-            where='/', name='XYZList', atom=self.tables.Int16Atom(),
-            shape=(0, n_atoms, 3))
+            where="/",
+            name="XYZList",
+            atom=self.tables.Int16Atom(),
+            shape=(0, n_atoms, 3),
+        )
 
     def seek(self, offset, whence=0):
         """Move to a new file position
@@ -393,7 +455,7 @@ class LH5TrajectoryFile(object):
             2: move relative to the end of file, offset should be <= 0.
             Seeking beyond the end of a file is not supported
         """
-        _check_mode(self.mode, ('r',))
+        _check_mode(self.mode, ("r",))
 
         if whence == 0 and offset >= 0:
             self._frame_index = offset
@@ -402,7 +464,7 @@ class LH5TrajectoryFile(object):
         elif whence == 2 and offset <= 0:
             self._frame_index = len(self._handle.root.XYZList) + offset
         else:
-            raise IOError('Invalid argument')
+            raise OSError("Invalid argument")
 
     def tell(self):
         """Current file position
@@ -428,7 +490,7 @@ class LH5TrajectoryFile(object):
     def __len__(self):
         "Number of frames in the file"
         if not self._open:
-            raise ValueError('I/O operation on closed file')
+            raise ValueError("I/O operation on closed file")
         return len(self._handle.root.XYZList)
 
     def __del__(self):
@@ -446,30 +508,20 @@ class LH5TrajectoryFile(object):
     # deprecation warnings if you dont use the new method names
     @property
     def _open_file(self):
-        if self.tables.__version__ >= '3.0.0':
-           return self.tables.open_file
-        return self.tables.openFile
+        return self.tables.open_file
 
     @property
     def _remove_node(self):
-        if self.tables.__version__ >= '3.0.0':
-            return self._handle.remove_node
-        return self._handle.removeNode
+        return self._handle.remove_node
 
     @property
     def _create_carray(self):
-        if self.tables.__version__ >= '3.0.0':
-            return self._handle.create_carray
-        return self._handle.createCArray
+        return self._handle.create_carray
 
     @property
     def _create_earray(self):
-        if self.tables.__version__ >= '3.0.0':
-            return self._handle.create_earray
-        return self._handle.createEArray
+        return self._handle.create_earray
 
     @property
     def _get_node(self):
-        if self.tables.__version__ >= '3.0.0':
-            return self._handle.get_node
-        return self._handle.getNode
+        return self._handle.get_node
