@@ -45,36 +45,31 @@
 # OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 # USE OR OTHER DEALINGS IN THE SOFTWARE.
 ##############################################################################
-"""Load an md.Topology from CHARMM/XPLOR PSF files
-"""
+"""Load an md.Topology from CHARMM/XPLOR PSF files"""
 
 # Written by Jason Swails <jason.swails@gmail.com> 9/8/2014
 # This code was mostly stolen and stripped down from ParmEd
 
-##############################################################################
-# Imports
-##############################################################################
-
-from __future__ import print_function, division
-
-from mdtraj.core import topology, element as elem
+from mdtraj.core import element as elem
+from mdtraj.core import topology
 from mdtraj.formats import pdb
 from mdtraj.utils.unit import unit_definitions as u
 
-__all__ = ['load_psf']
+__all__ = ["load_psf"]
 
-##############################################################################
-# Functions
-##############################################################################
 
 class PSFError(Exception):
-    """ Raised upon problems parsing a PSF file """
+    """Raised upon problems parsing a PSF file"""
+
     pass
 
+
 class _PSFEOF(Exception):
-    """ Raised when EOF is hit on the parsed PSF """
+    """Raised when EOF is hit on the parsed PSF"""
+
     pass
 
+
 def _convert(string, type, message):
     """Converts a string to the desired data type, making sure to raise PSFError
     with the given message in the case of a failure.
@@ -95,7 +90,8 @@ def _convert(string, type, message):
     try:
         return type(string)
     except ValueError:
-        raise PSFError('Could not convert %s [%s]' % (message, string))
+        raise PSFError(f"Could not convert {message} [{string}]")
+
 
 def _parse_psf_section(psf):
     """Parses a section of the PSF file, returning the data as a list of integer
@@ -110,7 +106,7 @@ def _parse_psf_section(psf):
     Returns
     -------
     (title, pointers, data)
-    
+
     title : str
         The label of the PSF section we are parsing
     pointers : (int/tuple of ints)
@@ -127,28 +123,28 @@ def _parse_psf_section(psf):
     line = psf.readline()
     while not line.strip():
         if not line:
-            raise _PSFEOF('Unexpected EOF in PSF file')
+            raise _PSFEOF("Unexpected EOF in PSF file")
         else:
             line = psf.readline()
-    if '!' in line:
-        words = line[:line.index('!')].split()
-        title = line[line.index('!')+1:].strip().upper()
+    if "!" in line:
+        words = line[: line.index("!")].split()
+        title = line[line.index("!") + 1 :].strip().upper()
         # Strip out the description
-        if ':' in title:
-            title = title[:title.index(':')]
+        if ":" in title:
+            title = title[: title.index(":")]
     else:
-        raise PSFError('Could not determine section title')
+        raise PSFError("Could not determine section title")
     if len(words) == 1:
-        pointers = _convert(words[0], int, 'pointer')
+        pointers = _convert(words[0], int, "pointer")
     else:
-        pointers = tuple([_convert(w, int, 'pointer') for w in words])
+        pointers = tuple([_convert(w, int, "pointer") for w in words])
     line = psf.readline().strip()
-    if not line and title.startswith('NNB'):
+    if not line and title.startswith("NNB"):
         # This will correctly handle the NNB section (which has a spurious blank
         # line)
         line = psf.readline().strip()
     data = []
-    if title == 'NATOM' or title == 'NTITLE':
+    if title == "NATOM" or title == "NTITLE":
         # Store these two sections as strings (ATOM section we will parse
         # later). The rest of the sections are integer pointers
         while line:
@@ -157,10 +153,11 @@ def _parse_psf_section(psf):
     else:
         while line:
             words = line.split()
-            data.extend([_convert(w, int, 'PSF data') for w in words])
+            data.extend([_convert(w, int, "PSF data") for w in words])
             line = psf.readline().strip()
     return title, pointers, data
-    
+
+
 def load_psf(fname, **kwargs):
     """Load a CHARMM or XPLOR PSF file from disk
 
@@ -191,11 +188,11 @@ def load_psf(fname, **kwargs):
     """
 
     top = topology.Topology()
-    
-    with open(fname, 'r') as f:
+
+    with open(fname) as f:
         line = f.readline()
-        if not line.startswith('PSF'):
-            raise PSFError('Unrecognized PSF file.')
+        if not line.startswith("PSF"):
+            raise PSFError("Unrecognized PSF file.")
 
         # Store all of the sections and store them in a dict
         f.readline()
@@ -207,26 +204,27 @@ def load_psf(fname, **kwargs):
                 break
             psfsections[sec] = (ptr, data)
             # We only have to parse up to the NBOND section
-            if sec == 'NBOND': break
+            if sec == "NBOND":
+                break
 
     prev_residue = (None, None, None)
 
     pdb.PDBTrajectoryFile._loadNameReplacementTables()
 
-    natom = _convert(psfsections['NATOM'][0], int, 'natom')
+    natom = _convert(psfsections["NATOM"][0], int, "natom")
     last_chain = None
     for i in range(natom):
-        words = psfsections['NATOM'][1][i].split()
-        atid = _convert(words[0], int, 'atom index')
+        words = psfsections["NATOM"][1][i].split()
+        atid = _convert(words[0], int, "atom index")
         if atid != i + 1:
-            raise PSFError('Nonsequential atom indices detected!')
+            raise PSFError("Nonsequential atom indices detected!")
         segid = words[1]
-        resid = _convert(words[2], int, 'residue number')
+        resid = _convert(words[2], int, "residue number")
         rname = words[3]
         name = words[4]
-#       attype = words[5]
-#       charge = _convert(words[6], float, 'partial atomic charge')
-        mass = _convert(words[7], float, 'atomic mass')
+        #       attype = words[5]
+        #       charge = _convert(words[6], float, 'partial atomic charge')
+        mass = _convert(words[7], float, "atomic mass")
         if last_chain != segid:
             c = top.add_chain()
             last_chain = segid
@@ -249,29 +247,29 @@ def load_psf(fname, **kwargs):
         # these 'weird' ion names, look up the element by mass. If the mass is
         # 0, assume a lone pair
         upper = name.upper()
-        if upper.startswith('CLA'):
+        if upper.startswith("CLA"):
             element = elem.chlorine
-        elif upper.startswith('SOD'):
+        elif upper.startswith("SOD"):
             element = elem.sodium
-        elif upper.startswith('POT'):
+        elif upper.startswith("POT"):
             element = elem.potassium
-        elif upper == 'CAL':
+        elif upper == "CAL":
             element = elem.calcium
         elif mass == 0:
             element = elem.virtual
         else:
-            element = elem.Element.getByMass(mass*u.dalton)
+            element = elem.Element.getByMass(mass * u.dalton)
         top.add_atom(name, element, r)
 
     # Add bonds to the topology
     atoms = list(top.atoms)
-    bond_data = psfsections['NBOND'][1]
-    nbond = _convert(psfsections['NBOND'][0], int, 'number of bonds')
+    bond_data = psfsections["NBOND"][1]
+    nbond = _convert(psfsections["NBOND"][0], int, "number of bonds")
     if len(bond_data) != nbond * 2:
-        raise PSFError('Got %d indexes for %d bonds' % (len(bond_data), nbond))
+        raise PSFError("Got %d indexes for %d bonds" % (len(bond_data), nbond))
 
     for i in range(nbond):
         i2 = i * 2
-        top.add_bond(atoms[bond_data[i2]-1], atoms[bond_data[i2+1]-1])
+        top.add_bond(atoms[bond_data[i2] - 1], atoms[bond_data[i2 + 1] - 1])
 
     return top
