@@ -3,7 +3,8 @@ Registry for trajectory file formats, so that the appropriate file
 object and loader can be resolved based on the filename extension.
 """
 
-class FormatRegistry(object):
+
+class FormatRegistry:
     """Registry for trajectory file objects.
 
     Examples
@@ -15,6 +16,7 @@ class FormatRegistry(object):
     >>> print FormatRegistry.loaders['.xyz']
     <function load_xyz at 0x1004a15f0>
     """
+
     loaders = {}
     fileobjects = {}
 
@@ -23,6 +25,7 @@ class FormatRegistry(object):
         def decorator(f):
             cls.loaders[extension] = f
             return f
+
         return decorator
 
     @classmethod
@@ -30,8 +33,10 @@ class FormatRegistry(object):
         def decorator(f):
             cls.fileobjects[extension] = f
             return f
+
         return decorator
 
+
 # Make a single instance of this class, and then
 # get rid of the class object. This should be
 # treated as a singleton
