@@ -1,20 +1,22 @@
 import os
 import os.path
-import numpy as np
 import tempfile
-import mdtraj as md
+
+import numpy as np
 import pytest
 
+import mdtraj as md
+
 
 def test_1(get_fn):
     # https://github.com/mdtraj/mdtraj/issues/438
     try:
         dir = tempfile.mkdtemp()
-        fn = os.path.join(dir, 'temp.npy')
-        traj = md.load(get_fn('frame0.h5'))
+        fn = os.path.join(dir, "temp.npy")
+        traj = md.load(get_fn("frame0.h5"))
         np.save(fn, traj.xyz)
 
-        traj.xyz = np.load(fn, mmap_mode='r')
+        traj.xyz = np.load(fn, mmap_mode="r")
 
         # since traj isn't precentered, this requires centering
         # the coordinates which is done inplace. but that's not possible
@@ -23,7 +25,7 @@ def test_1(get_fn):
             md.rmsd(traj, traj, 0)
 
         # this should work
-        traj.xyz = np.load(fn, mmap_mode='c')
+        traj.xyz = np.load(fn, mmap_mode="c")
         md.rmsd(traj, traj, 0)
 
     finally:
@@ -36,13 +38,13 @@ def test_2(get_fn):
     # https://github.com/mdtraj/mdtraj/issues/438
     try:
         dir = tempfile.mkdtemp()
-        fn = os.path.join(dir, 'temp.npy')
-        traj = md.load(get_fn('frame0.h5'))
+        fn = os.path.join(dir, "temp.npy")
+        traj = md.load(get_fn("frame0.h5"))
         # precenter the coordinates
         traj.center_coordinates()
         traces = traj._rmsd_traces
         np.save(fn, traj.xyz)
-        traj.xyz = np.load(fn, mmap_mode='r')
+        traj.xyz = np.load(fn, mmap_mode="r")
         traj._rmsd_traces = traces
 
         with pytest.raises(ValueError):
