@@ -207,14 +207,13 @@ def precision2(fext1, fext2):
 
 
 def test_read_path(ref_traj, get_fn, monkeypatch):
-
-    if ref_traj.fext in ('nc'):
+    if ref_traj.fext in ("nc"):
         # Running with scipy
         with monkeypatch.context() as m:
-            m.setitem(sys.modules, 'netCDF4', None)
+            m.setitem(sys.modules, "netCDF4", None)
             md.load(Path(get_fn(ref_traj.fn)), top=get_fn("native.pdb"))
 
-    md.load(Path(get_fn(ref_traj.fn)), top=get_fn("native.pdb"))    
+    md.load(Path(get_fn(ref_traj.fn)), top=get_fn("native.pdb"))
 
 
 def test_write_path(write_traj, get_fn, monkeypatch):
@@ -230,12 +229,12 @@ def test_write_path(write_traj, get_fn, monkeypatch):
                 pytest.skip(f"{write_traj.fext} needs to write unitcells")
         t.save(Path(write_traj.fn))
 
-    if write_traj.fext in ('nc'):
+    if write_traj.fext in ("nc"):
         # Running with scipy
         with monkeypatch.context() as m:
-            m.setitem(sys.modules, 'netCDF4', None)
+            m.setitem(sys.modules, "netCDF4", None)
             test_base(write_traj, get_fn)
-    
+
     test_base(write_traj, get_fn)
 
 
@@ -248,25 +247,26 @@ def test_read_write(ref_traj, write_traj, get_fn, monkeypatch):
     def test_base(ref_traj, write_traj, get_fn):
         top = get_fn("native.pdb")
         t = md.load(get_fn(ref_traj.fn), top=top)
-    
+
         if t.unitcell_vectors is None:
             if write_traj.fext in ("dtr", "lammpstrj"):
                 pytest.skip(f"{write_traj.fext} needs to write unitcells")
-    
+
         t.save(write_traj.fn)
         t2 = md.load(write_traj.fn, top=top)
         eq(t.xyz, t2.xyz, decimal=precision2(ref_traj.fext, write_traj.fext))
         if has_time_info(write_traj.fext):
             eq(t.time, t2.time, decimal=3)
-    
-    if write_traj.fext in ('nc') or ref_traj.fext in ('nc'):
+
+    if write_traj.fext in ("nc") or ref_traj.fext in ("nc"):
         # Running with scipy
         with monkeypatch.context() as m:
-            m.setitem(sys.modules, 'netCDF4', None)
+            m.setitem(sys.modules, "netCDF4", None)
             test_base(ref_traj, write_traj, get_fn)
-    
+
     test_base(ref_traj, write_traj, get_fn)
 
+
 def test_load(ref_traj, get_fn, monkeypatch):
     def test_base(ref_traj, get_fn):
         nat = md.load(get_fn("native.pdb"))
@@ -283,7 +283,7 @@ def test_load(ref_traj, get_fn, monkeypatch):
             top=nat,
             discard_overlapping_frames=True,
         )
-    
+
         # these don't actually overlap, so discard_overlapping_frames should
         # have no effect. the overlap is between the last frame of one and the
         # first frame of the next.
@@ -291,12 +291,12 @@ def test_load(ref_traj, get_fn, monkeypatch):
         assert eq(t0.n_frames * num_block, t2.n_frames)
         assert eq(t3.n_frames, t2.n_frames)
 
-    if ref_traj.fext in ('nc'):
+    if ref_traj.fext in ("nc"):
         # Running with scipy
         with monkeypatch.context() as m:
-            m.setitem(sys.modules, 'netCDF4', None)
+            m.setitem(sys.modules, "netCDF4", None)
             test_base(ref_traj, get_fn)
-    
+
     test_base(ref_traj, get_fn)
 
 
@@ -346,22 +346,23 @@ def test_center_aind(get_fn):
     eq(mu0, mu2)
 
 
+@pytest.mark.filterwarnings("ignore:atom_indices are not monotonically")
 def test_float_atom_indices_exception(ref_traj, get_fn, monkeypatch):
     def test_base(ref_traj, get_fn):
         # Is an informative error message given when you supply floats for atom_indices?
         top = md.load(get_fn("native.pdb")).topology
-    
+
         try:
             md.load(get_fn(ref_traj.fn), atom_indices=[0.5, 1.3], top=top)
         except ValueError as e:
             assert e.args[0] == "indices must be of an integer type. float64 is not an integer type"
 
-    if ref_traj.fext in ('nc'):
+    if ref_traj.fext in ("nc"):
         # Running with scipy
         with monkeypatch.context() as m:
-            m.setitem(sys.modules, 'netCDF4', None)
+            m.setitem(sys.modules, "netCDF4", None)
             test_base(ref_traj, get_fn)
-    
+
     test_base(ref_traj, get_fn)
 
 
@@ -414,7 +415,7 @@ def test_restrict_atoms_not_inplace(get_fn):
 def test_array_vs_matrix(get_fn):
     top = md.load(get_fn("native.pdb")).topology
     xyz = np.random.randn(1, 22, 3)
-    xyz_mat = np.matrix(xyz)
+    xyz_mat = np.asarray(xyz)
     t1 = md.Trajectory(xyz, top)
     t2 = md.Trajectory(xyz_mat, top)
 
@@ -442,11 +443,11 @@ def test_load_combination(ref_traj, get_fn, monkeypatch):
     def test_base(ref_traj, get_fn):
         topology = md.load(get_fn("native.pdb")).topology
         ainds = np.array([a.index for a in topology.atoms if a.element.symbol == "C"])
-    
+
         no_kwargs = md.load(get_fn(ref_traj.fn), top=topology)
         strided3 = md.load(get_fn(ref_traj.fn), top=topology, stride=3)
         subset = md.load(get_fn(ref_traj.fn), top=topology, atom_indices=ainds)
-    
+
         # test 1
         t1 = no_kwargs
         t2 = strided3
@@ -455,7 +456,7 @@ def test_load_combination(ref_traj, get_fn, monkeypatch):
         if t1.unitcell_vectors is not None:
             assert eq(t1.unitcell_vectors[::3], t2.unitcell_vectors)
         assert eq(t1.topology, t2.topology)
-    
+
         # test 2
         t1 = no_kwargs
         t2 = subset
@@ -465,12 +466,12 @@ def test_load_combination(ref_traj, get_fn, monkeypatch):
             assert eq(t1.unitcell_vectors, t2.unitcell_vectors)
         assert eq(t1.topology.subset(ainds), t2.topology)
 
-    if ref_traj.fext in ('nc'):
+    if ref_traj.fext in ("nc"):
         # Running with scipy
         with monkeypatch.context() as m:
-            m.setitem(sys.modules, 'netCDF4', None)
+            m.setitem(sys.modules, "netCDF4", None)
             test_base(ref_traj, get_fn)
-    
+
     test_base(ref_traj, get_fn)
 
 
@@ -544,7 +545,7 @@ def test_seek_read_mode(ref_traj, get_fn, monkeypatch):
         kwargs = {}
         if fobj is md.formats.MDCRDTrajectoryFile:
             kwargs = {"n_atoms": 22}
-    
+
         with fobj(get_fn(fn), **kwargs) as f:
             for i in range(100):
                 r = np.random.rand()
@@ -583,15 +584,15 @@ def test_seek_read_mode(ref_traj, get_fn, monkeypatch):
                     offset = np.random.randint(100)
                     f.seek(offset, 0)
                     point = offset
-    
+
                 eq(f.tell(), point)
 
-    if ref_traj.fext in ('nc'):
+    if ref_traj.fext in ("nc"):
         # Running with scipy
         with monkeypatch.context() as m:
-            m.setitem(sys.modules, 'netCDF4', None)
+            m.setitem(sys.modules, "netCDF4", None)
             test_base(ref_traj, get_fn)
-    
+
     test_base(ref_traj, get_fn)
 
 
@@ -603,7 +604,7 @@ def test_load_frame(ref_traj, get_fn, monkeypatch):
         trajectory = md.load(get_fn(ref_traj.fn), top=get_fn("native.pdb"))
         rand = np.random.randint(len(trajectory))
         frame = md.load_frame(get_fn(ref_traj.fn), index=rand, top=get_fn("native.pdb"))
-    
+
         if ref_traj.fobj is md.formats.DTRTrajectoryFile:
             pytest.xfail("DTR doesn't load a single frame properly")
         eq(trajectory[rand].xyz, frame.xyz)
@@ -611,12 +612,12 @@ def test_load_frame(ref_traj, get_fn, monkeypatch):
         if has_time_info(ref_traj.fext):
             eq(trajectory[rand].time, frame.time)
 
-    if ref_traj.fext in ('nc'):
+    if ref_traj.fext in ("nc"):
         # Running with scipy
         with monkeypatch.context() as m:
-            m.setitem(sys.modules, 'netCDF4', None)
+            m.setitem(sys.modules, "netCDF4", None)
             test_base(ref_traj, get_fn)
-    
+
     test_base(ref_traj, get_fn)
 
 
@@ -633,12 +634,12 @@ def test_iterload(write_traj, get_fn, monkeypatch):
 
     def test_base(write_traj, get_fn):
         t_ref = md.load(get_fn("frame0.h5"))[:20]
-    
+
         if write_traj.fext in ("ncrst", "rst7"):
             pytest.skip("Only 1 frame per file format")
-    
+
         t_ref.save(write_traj.fn)
-    
+
         for stride in [1, 2, 3]:
             loaded = md.load(write_traj.fn, top=t_ref, stride=stride)
             iterloaded = functools.reduce(
@@ -650,12 +651,12 @@ def test_iterload(write_traj, get_fn, monkeypatch):
             eq(loaded.unitcell_angles, iterloaded.unitcell_angles)
             eq(loaded.unitcell_lengths, iterloaded.unitcell_lengths)
 
-    if write_traj.fext in ('nc'):
+    if write_traj.fext in ("nc"):
         # Running with scipy
         with monkeypatch.context() as m:
-            m.setitem(sys.modules, 'netCDF4', None)
+            m.setitem(sys.modules, "netCDF4", None)
             test_base(write_traj, get_fn)
-    
+
     test_base(write_traj, get_fn)
 
 
@@ -670,7 +671,7 @@ def test_iterload_skip(ref_traj, get_fn, monkeypatch):
     def test_base(ref_traj, get_fn):
         top = md.load(get_fn("native.pdb"))
         t_ref = md.load(get_fn(ref_traj.fn), top=top)
-    
+
         for cs in [0, 1, 11, 100]:
             for skip in [0, 1, 20, 101]:
                 t = functools.reduce(
@@ -681,12 +682,12 @@ def test_iterload_skip(ref_traj, get_fn, monkeypatch):
                 eq(t_ref.time[skip:], t.time)
                 eq(t_ref.topology, t.topology)
 
-    if ref_traj.fext in ('nc'):
+    if ref_traj.fext in ("nc"):
         # Running with scipy
         with monkeypatch.context() as m:
-            m.setitem(sys.modules, 'netCDF4', None)
+            m.setitem(sys.modules, "netCDF4", None)
             test_base(ref_traj, get_fn)
-    
+
     test_base(ref_traj, get_fn)
 
 
@@ -731,12 +732,12 @@ def test_save_load(write_traj, get_fn, monkeypatch):
             eq(t.unitcell_angles, t_ref.unitcell_angles)
             eq(t.unitcell_lengths, t_ref.unitcell_lengths)
 
-    if write_traj.fext in ('nc'):
+    if write_traj.fext in ("nc"):
         # Running with scipy
         with monkeypatch.context() as m:
-            m.setitem(sys.modules, 'netCDF4', None)
+            m.setitem(sys.modules, "netCDF4", None)
             test_base(write_traj, get_fn)
-    
+
     test_base(write_traj, get_fn)
 
 
@@ -749,12 +750,12 @@ def test_force_overwrite(write_traj, get_fn, monkeypatch):
         open(write_traj.fn, "w").close()
         t_ref.save(write_traj.fn, force_overwrite=True)
 
-    if write_traj.fext in ('nc'):
+    if write_traj.fext in ("nc"):
         # Running with scipy
         with monkeypatch.context() as m:
-            m.setitem(sys.modules, 'netCDF4', None)
+            m.setitem(sys.modules, "netCDF4", None)
             test_base(write_traj, get_fn)
-    
+
     test_base(write_traj, get_fn)
 
 
@@ -765,12 +766,12 @@ def test_force_noverwrite(write_traj, get_fn, monkeypatch):
         with pytest.raises(IOError):
             t_ref.save(write_traj.fn, force_overwrite=False)
 
-    if write_traj.fext in ('nc'):
+    if write_traj.fext in ("nc"):
         # Running with scipy
         with monkeypatch.context() as m:
-            m.setitem(sys.modules, 'netCDF4', None)
+            m.setitem(sys.modules, "netCDF4", None)
             test_base(write_traj, get_fn)
-    
+
     test_base(write_traj, get_fn)
 
 
@@ -784,7 +785,10 @@ def test_open_and_load(get_fn):
         else:
             md.open(get_fn(file))
 
-        md.load(get_fn(file), top=get_fn("native.pdb"))
+        if file.endswith(".arc"):
+            md.load(get_fn(file), top=get_fn("4waters.pdb"))
+        else:
+            md.load(get_fn(file), top=get_fn("frame0.pdb"))
 
 
 def test_length(get_fn):
@@ -818,19 +822,18 @@ def test_unitcell(write_traj, get_fn, monkeypatch):
     if write_traj.fext in ["rst7", "ncrst", "lammpstrj", "dtr"]:
         pytest.xfail(f"{write_traj.fext} seems to need unit vectors")
 
-
     def test_base(write_traj, get_fn):
         top = md.load(get_fn("native.pdb")).restrict_atoms(range(5)).topology
         t = md.Trajectory(xyz=np.random.randn(100, 5, 3), topology=top)
         t.save(write_traj.fn)
         assert eq(md.load(write_traj.fn, top=top).unitcell_vectors, None)
 
-    if write_traj.fext in ('nc'):
+    if write_traj.fext in ("nc"):
         # Running with scipy
         with monkeypatch.context() as m:
-            m.setitem(sys.modules, 'netCDF4', None)
+            m.setitem(sys.modules, "netCDF4", None)
             test_base(write_traj, get_fn)
-    
+
     test_base(write_traj, get_fn)
 
 
@@ -891,6 +894,22 @@ def test_smooth(get_fn):
     eq(output, test)
 
 
+def test_make_whole(get_fn):
+    t1 = md.load(get_fn("water1_pbc.pdb"))
+    t2 = md.load(get_fn("water2_pbc.pdb"))
+
+    t1.make_molecules_whole(inplace=True)
+    t2.make_molecules_whole(inplace=True)
+
+    # Test that bond lengths are preserved
+    bonds1 = [(a1.index, a2.index) for a1, a2 in t1.topology._bonds]
+    bond_lenghts1 = [np.linalg.norm(t1.xyz[0, a1] - t1.xyz[0, a2]) for a1, a2 in bonds1]
+    bonds2 = [(a1.index, a2.index) for a1, a2 in t2.topology._bonds]
+    bond_lenghts2 = [np.linalg.norm(t2.xyz[0, a1] - t2.xyz[0, a2]) for a1, a2 in bonds2]
+
+    assert np.allclose(bond_lenghts1, bond_lenghts2)
+
+
 @pytest.mark.skip(reason="Broken, maybe only on Python 3.11")
 def test_image_molecules(get_fn):
     # Load trajectory with periodic box
@@ -929,6 +948,15 @@ def test_load_with_atom_indices(get_fn):
     eq(t1.time, t2.time)
 
 
+@pytest.mark.filterwarnings("ignore:atom_indices are not monotonically")
+def test_atom_slicing(get_fn):
+    t = md.load(get_fn("frame0.xtc"), top=get_fn("frame0.gro"))
+    t1 = t.atom_slice([0, 1])
+    t2 = t.atom_slice([1, 0])
+    eq(t1.xyz, t2.xyz)
+    eq(t1.time, t2.time)
+
+
 def test_load_with_frame(get_fn):
     t1 = md.load(get_fn("frame0.xtc"), top=get_fn("frame0.pdb"), frame=3)
     t2 = md.load(get_fn("frame0.xtc"), top=get_fn("frame0.pdb"))
